# Batch runs - print command

The `--print-cmd` option will print both the batch operation and each
of the trials that would be generated by the batch.

We'll use the `optimizers` sample project:

    >>> project = Project(sample("projects", "optimizers"))

Here's a batch run with three values:

    >>> project.run("echo.py", flags={"x": [1,2,3]}, print_cmd=True)
    ??? -um guild.batch_main
    ... -um guild.op_main echo --x 1 --y 2 --z a
    ... -um guild.op_main echo --x 2 --y 2 --z a
    ... -um guild.op_main echo --x 3 --y 2 --z a

And using the `random` optimizer:

    >>> project.run("echo.py", flags={"x": [1,2,3]}, optimizer="random",
    ...             max_trials=3, print_cmd=True)
    ??? -um guild.plugins.random_main
    ... -um guild.op_main echo --x ... --y 2 --z a
    ... -um guild.op_main echo --x ... --y 2 --z a
    ... -um guild.op_main echo --x ... --y 2 --z a

Note we can't assert the values for `x` because they're randomly
generated.

Any optimizers that are sequential don't support printing of commands.

    >>> project.run("echo.py", flags={"x": [1,2,3]}, optimizer="gp",
    ...             max_trials=3, print_cmd=True)
    ??? -um guild.plugins.skopt_gp_main
    ERROR: [guild] optimizer does not support printing trials command
    <exit 1>

    >>> project.run("echo.py", flags={"x": [1,2,3]}, optimizer="forest",
    ...             max_trials=3, print_cmd=True)
    ??? -um guild.plugins.skopt_forest_main
    ERROR: [guild] optimizer does not support printing trials command
    <exit 1>

    >>> project.run("echo.py", flags={"x": [1,2,3]}, optimizer="gbrt",
    ...             max_trials=3, print_cmd=True)
    ??? -um guild.plugins.skopt_gbrt_main
    ERROR: [guild] optimizer does not support printing trials command
    <exit 1>
